@@ -25,29 +25,27 @@ class _TaskContext(object):
     def get_task_id(self):
         return self._context.address.identity
 
+    def get_caller_address(self):
+        return f'{self._context.caller.namespace}/{self._context.caller.type}'
+
     def get_caller_id(self):
         return None if self._context.caller.identity == "" else self._context.caller.identity
 
-    def unpack(self, key:str, cls:Callable[[], object]):
-        state = self._context[key]
-        if state is None:
-            return None
-        else:
-            value = cls()
-            state.Unpack(value)
-            return value
+    def unpack(self, key:str, object_type):
+        return self._context.state(key).unpack(object_type)
 
     def pack_and_reply(self, message):
         self._context.pack_and_reply(message)
 
     def pack_and_save(self, key:str, value):
-        any = Any()
-        any.Pack(value)
-        self._context[key] = any
+        self._context.state(key).pack(value)
 
     def pack_and_send(self, destination, task_id, request):
         self._context.pack_and_send(destination, task_id, request)
 
+    def pack_and_send_after(self, delay, destination, task_id, request):
+        self._context.pack_and_send_after(delay, destination, task_id, request)
+
     def pack_and_send_egress(self, topic, value):
         any = Any()
         any.Pack(value)
@@ -63,6 +61,11 @@ class _TaskContext(object):
     def update_state(self, updates:dict):
         self._state.update(updates)
 
+    def pack_and_update_state(self, key, value):
+        any = Any()
+        any.Pack(value)
+        self._state.update({key: any})
+
     def __enter__(self):
         return self
 
